# Generated by Django 5.0.13 on 2025-03-20 04:42

from django.db import migrations, models

from openbook_common.utils.model_loaders import get_community_model, get_task_model


def communities_table_name() -> str:
    CommunityModel = get_community_model()
    return CommunityModel._meta.db_table


def tasks_table_name() -> str:
    TasksModel = get_task_model()
    return TasksModel._meta.db_table


def migration_sql(table_name) -> str:
    return f"""
        UPDATE {table_name}
        SET geolocation_geojson = jsonb_build_object(
            'type', 'Point',
            'coordinates', ARRAY[
                ST_X(geolocation::geometry),
                ST_Y(geolocation::geometry)
            ]
        )
        WHERE geolocation IS NOT NULL;
    """


def reverse_migration_sql(table_name) -> str:
    return f"""
        UPDATE {table_name}
        SET geolocation_geojson = NULL;
    """


def run_migration(apps, schema_editor):
    schema_editor.execute(migration_sql(communities_table_name()))
    schema_editor.execute(migration_sql(tasks_table_name()))


def reverse_migration(apps, schema_editor):
    schema_editor.execute(reverse_migration_sql(tasks_table_name()))
    schema_editor.execute(reverse_migration_sql(communities_table_name()))


class Migration(migrations.Migration):
    dependencies = [
        ("openbook_communities", "0045_task_openbook_co_skills__85edfe_gin"),
    ]

    operations = [
        migrations.AddField(
            model_name="community",
            name="geolocation_geojson",
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="task",
            name="geolocation_geojson",
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.RunPython(run_migration, reverse_migration),
    ]
